@@ -27,10 +27,16 @@ class BaseAnalyzer:
             return len(text.split())  # en - split by space
 
     @staticmethod
-    def get_text_token_length(text: str, tokenizer=None):
-        if not tokenizer:
+    def get_text_token_length(text: str, tokenizer='bert_tokenizer'):
+        if tokenizer == 'bert_tokenizer':
             from transformers import BertTokenizer
             tokenizer = BertTokenizer.from_pretrained('bert-base-multilingual-cased')
+        elif tokenizer == 'mt5_tokenizer':
+            from transformers import T5Tokenizer
+            tokenizer = T5Tokenizer.from_pretrained('google/mt5-base')
+        else:
+            from transformers import T5Tokenizer
+            tokenizer = T5Tokenizer.from_pretrained('google/mt5-base')
         return len(tokenizer.tokenize(text))
 
     @staticmethod
