@@ -164,7 +164,7 @@ class NerT5:
 
     def eval(self, eval_data: pd.DataFrame, check_in_input_text: bool = False, delimiter='|',
              tokenizer=None, use_sliding_window=False, sliding_window=None, stride=0.8,
-             pos_neg_ratio=None, use_multi_gpus=None, self_metric=False):
+             pos_neg_ratio=None, use_multi_gpus=None, self_metric=False,wandb_log=None):
         # deal_with_dt
         eval_data = self._deal_with_df(eval_data, sliding_window=False)
         eval_size = eval_data.shape[0]
@@ -188,11 +188,12 @@ class NerT5:
                                                       pos_neg_ratio=pos_neg_ratio, use_multi_gpus=use_multi_gpus,
                                                       self_metric=self_metric)
 
+            if wandb_log:
+                wandb.log(wandb_log)
             wandb_log = {"eval_size": eval_size}
             for k, v in eval_res.items():
                 wandb_log.update({k: v.iloc[2, -1]})
             wandb.log(wandb_log)
-
             logger.info('eval finished!!!')
             end_time = time.time()
             need_time = round((end_time - start_time) / eval_size, 5)
